@@ -1,4 +1,3 @@
-import datetime
 import gzip
 import json
 
@@ -12,37 +11,18 @@ def __decode_and_decompress(url):
 
 
 def __get_index_file():
-    index = __decode_and_decompress("http://198.46.233.213/index/index.json.gz")
+    index = __decode_and_decompress("http://107.175.127.29/index.json.gz")
 
     return index
 
 
-def update_index_file():
-    global __index, __relic_dict, __price_dict, __ducat_dict, __required_dict, __nv_relics, __type_dict
-    __index.update(__get_index_file())
-    __relic_dict.update(__index['relics'])
-    __price_dict.update(__index['prices'])
-    __ducat_dict.update(__index['ducats'])
-    __required_dict.update(__index['required_count'])
-    __nv_relics = __index['non_vaulted']
-    __type_dict.update(__index['types'])
-
-
-__index = {}
-__relic_dict = {}
-__price_dict = {}
-__ducat_dict = {}
-__required_dict = {}
-__nv_relics = []
-__type_dict = {}
-
-update_index_file()
-
-
-def index_last_modified():
-    last_modified = requests.head("http://198.46.233.213/index/index.json.gz").headers['Last-Modified']
-    return datetime.datetime.strptime(last_modified, '%a, %d %b %Y %H:%M:%S %Z')
-
+__index = __get_index_file()
+__relic_dict = __index['relics']
+__price_dict = __index['prices']
+__ducat_dict = __index['ducats']
+__required_dict = __index['required_count']
+__nv_relics = __index['non_vaulted']
+__type_dict = __index['types']
 
 __rarity_dict = {
     'i': {
@@ -279,3 +259,4 @@ def get_set_required(set_name):
         required_amount[item] = get_required_amount(item)
 
     return required_amount
+
